==> fred-akm-ng_1.1.2.orig.tar.gz: fred-akm-ng-1.1.2/src/logger/log_entry_factory.cc <==
/*
 * Copyright (C) 2021  CZ.NIC, z. s. p. o.
 *
 * This file is part of FRED.
 *
 * FRED is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FRED is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FRED.  If not, see <https://www.gnu.org/licenses/>.
 */
#include "src/logger/log_entry_factory.hh"
#include "src/logger/impl/service_type.hh"
#include "src/logger/impl/to_log_entry_property.hh"
#include "src/logger/impl/to_object_reference.hh"

#include <libgrill/logger/create_log_entry.hh>

namespace Fred {
namespace Akm {
namespace Logger {

LogEntryFactory::LogEntryFactory(LibGrill::Connection<LibGrill::Service::Logger>& _connection)
    : connection_(_connection)
{
}

template<LogEntryType T>
LogEntry<T> LogEntryFactory::create_log_entry(const DomainId& _domain_id, const DomainFqdn& _domain_fqdn)
{
    ::LibGrill::Logger::CreateLogEntryRequest request(
            to_libgrill_log_entry_type<T>(),
            to_libgrill_log_entry_service<ServiceType::admin>());
    request.add_object_reference(_domain_id);
    request.add_property(_domain_fqdn);

    const auto log_entry_id = ::LibGrill::Logger::create_log_entry(connection_, request);
    LogEntry<T> log_entry(connection_, log_entry_id, _domain_fqdn);
    return log_entry;
}

template
LogEntry<LogEntryType::akm_turn_off> LogEntryFactory::create_log_entry(const DomainId&, const DomainFqdn&);

template
LogEntry<LogEntryType::akm_turn_on> LogEntryFactory::create_log_entry(const DomainId&, const DomainFqdn&);

template
LogEntry<LogEntryType::akm_rollover> LogEntryFactory::create_log_entry(const DomainId&, const DomainFqdn&);

} // namespace Fred::Akm::Logger
} // namespace Fred::Akm
} // namespace Fred

==> fred-akm-ng_1.1.5.orig.tar.gz: fred-akm-ng-1.1.5/src/logger/log_entry_factory.cc <==
/*
 * Copyright (C) 2021-2024  CZ.NIC, z. s. p. o.
 *
 * This file is part of FRED.
 *
 * FRED is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FRED is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FRED.  If not, see <https://www.gnu.org/licenses/>.
 */

#include "src/logger/log_entry_factory.hh"
#include "src/logger/impl/service_type.hh"
#include "src/logger/impl/to_log_entry_property.hh"
#include "src/logger/impl/to_object_reference.hh"

#include <libgrill/logger/create_log_entry.hh>

namespace Fred {
namespace Akm {
namespace Logger {

LogEntryFactory::LogEntryFactory(LibGrill::Connection<LibGrill::Service::Logger>& _connection)
    : connection_(_connection)
{
}

template<LogEntryType T>
std::unique_ptr<LogEntry<T>> LogEntryFactory::create_log_entry(const DomainId& _domain_id, const DomainFqdn& _domain_fqdn)
{
    ::LibGrill::Logger::CreateLogEntryRequest request(
            to_libgrill_log_entry_type<T>(),
            to_libgrill_log_entry_service<ServiceType::admin>());
    request.add_object_reference(_domain_id);
    request.add_property(_domain_fqdn);

    const auto log_entry_id = ::LibGrill::Logger::create_log_entry(connection_, request);
    return std::unique_ptr<LogEntry<T>>{new LogEntry<T>{connection_, log_entry_id, _domain_fqdn}};
}

template
std::unique_ptr<LogEntry<LogEntryType::akm_turn_off>> LogEntryFactory::create_log_entry(const DomainId&, const DomainFqdn&);

template
std::unique_ptr<LogEntry<LogEntryType::akm_turn_on>> LogEntryFactory::create_log_entry(const DomainId&, const DomainFqdn&);

template
std::unique_ptr<LogEntry<LogEntryType::akm_rollover>> LogEntryFactory::create_log_entry(const DomainId&, const DomainFqdn&);

} // namespace Fred::Akm::Logger
} // namespace Fred::Akm
} // namespace Fred
